@@ -14,7 +14,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: aic.c,v 1.16 2002/08/12 21:13:51 beerli Exp $ 
+$Id: aic.c,v 1.18 2002/11/14 18:38:03 beerli Exp $ 
 -------------------------------------------------------*/
 #include "migration.h"
 #include "tools.h"
@@ -60,6 +60,8 @@ void print_aicfile(aic_fmt **aicvec, long *aicnum, nr_fmt *nr);
 void print_progress_aic(boolean add
                             , aic_fmt **aicvec, long *aicnum, nr_fmt *nr, long numparam, long freeparam);
 
+long find_paramnum(world_fmt *world, char *connect);
+
 // changes a linear matrix of ddd mm mm mm
 // to a diagonal matrix dmm mdm mmd
 // it destroys pattern
@@ -113,10 +115,6 @@ print_header_aic (nr_fmt * nr, double mleaic)
     FPRINTF (world->outfile, "\n\n\n Akaike's Information Criterion  (AIC)\n");
     FPRINTF (world->outfile, "=========================================\n\n");
     FPRINTF (world->outfile, "[Linearized migration matrix, x=diagonal]\n");
-    FPRINTF (world->outfile,
-             "%-*.*s            AIC     #param   Log(L)   LRT      Prob     Probc\n",
-             (int) MAX (18, nr->partsize + nr->numpop),
-             (int) (nr->partsize + nr->numpop), "Pattern");
 }
 
 // calculates akaike information score
@@ -182,10 +180,20 @@ void aic_print_driver(aic_fmt *aicvec, double mleaic, long aicnum, nr_fmt *nr, w
     long i;
     char *temppattern;
     boolean mldone=FALSE;
+    char dashes[100] = "----------------------------------------------------------------------------------------------------";
     temppattern = calloc (world->numpop2 + 1 + world->numpop, sizeof (char));
+    FPRINTF (world->outfile,
+             "%-*.*s  AIC     #param   Log(L)   LRT        Prob    Probc\n",
+             (int) MAX (18, nr->partsize + nr->numpop),
+             (int) (nr->partsize + nr->numpop), "Pattern");
+    FPRINTF (world->outfile,
+             "%-*.*s ---------- ---- ---------- ---------- ------- -------\n",
+             (int) MAX (18, nr->partsize + nr->numpop),
+             (int) (nr->partsize + nr->numpop), dashes);
+    
     for (i = 0; i < aicnum; i++)
     {
-        FPRINTF (world->outfile, "%-*.*s %20.5f %4li % f % f %f %f\n",
+        FPRINTF (world->outfile, "%-*.*s %10.5f %4li % 10.5f % 10.5f %6.5f %6.5f\n",
                  (int) MAX (18, nr->partsize + nr->numpop),
                  (int) (nr->partsize + nr->numpop),
                  reshuffle (temppattern, aicvec[i].pattern, nr->numpop),
@@ -194,11 +202,10 @@ void aic_print_driver(aic_fmt *aicvec, double mleaic, long aicnum, nr_fmt *nr, w
         if (aicvec[i].aic == mleaic && !mldone)
         {
             mldone = TRUE;
-            FPRINTF (world->outfile, "%-*.*s%21.21s-----\n",
+            FPRINTF (world->outfile, "%-*.*s %53.53s\n",
                      (int) MAX (18, nr->partsize + nr->numpop),
-                     (int) (nr->partsize + nr->numpop),
-                     "--------------------------------------------------------------------------------------------------------------------------------------------------------------",
-                     "---------------------");
+                     (int) (nr->partsize + nr->numpop),dashes,
+                  dashes);
         }
         free (aicvec[i].pattern);
     }
@@ -233,12 +240,12 @@ akaike_information (world_fmt * world, long *Gmax)
     if (kind == MULTILOCUS)
     {
         mle = world->atl[0][world->loci].param_like;
-        mleaic = -2. * mle + 2. * world->numpop2;
+        mleaic = -2. * mle + 2. * find_paramnum(world,NULL);
     }
     else
     {
         mle = world->atl[repstop == 1 ? 0 : repstop][0].param_like;
-        mleaic = -2. * mle + 2. * world->numpop2;
+        mleaic = -2. * mle + 2. * find_paramnum(world,NULL);
     }
     nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
 
@@ -561,3 +568,71 @@ legal_pattern (char *matrix, long numpop)
         return FALSE;
     return TRUE;
 }
+
+long find_paramnum(world_fmt *world, char *connect)
+{
+    long cc;
+    long tm;
+    long mm;
+    long mmm;
+    long ms;
+    long mss;
+    long total;
+    char *temp, *temp1, *temp2, *t;
+    
+    // checkout if GAMMA mutation rate
+    total = world->numpop * world->numpop + (world->options->gamma ? 1 : 0) ;
+    
+    if(connect==NULL)
+      {
+        // checkout zeroes and constants in custom migration matrix
+        // removes 1 for each zero and (constant>0)
+        total -= world->options->zeron + world->options->constn;
+        // checkout mean values
+        // removes number of parameters that are part of the average and adds
+        // 1 for average migrations and 1 for average thetas
+        total -= (world->options->tmn > 0 ? world->options->tmn - 1 : 0) + (world->options->mmn > 0 ? world->options->mmn - 1 : 0); 
+        // checkout symmetric values
+        // removes 1 parameter for each migration pair
+        total -= world->options->symn + world->options->sym2n;
+      }
+    else
+      {
+        temp1 = (char *) calloc(strlen(connect)+1, sizeof(char));
+        temp2 = (char *) calloc(strlen(connect)+1, sizeof(char));
+        temp = (char *) calloc(strlen(connect)+1, sizeof(char));
+        t = temp;
+        strcpy(temp1,connect);
+        temp2 = strtok(temp1," ;,:\n\t\r");
+        while(temp2!= NULL)
+          {
+            switch(temp2[0])
+              {
+                case '*': *t++ = '*'; break;
+                case 'c': *t++ = 'c'; break;
+                case 'm': *t++ = 'm'; break;
+                case 'M': *t++ = 'M'; break;
+                case 's': *t++ = 's'; break;
+                case 'S': *t++ = 'S'; break;
+                case ' ' : break;
+                default:
+                    *t++ = 'c';
+              }
+            temp2 = strtok(NULL," ;,:\n\t\r");
+          }
+        cc = scan_connect (temp, 0, world->numpop2, 'c');
+        tm = scan_connect (temp, 0, world->numpop, 'm');
+        mm = scan_connect (temp, world->numpop, world->numpop2, 'm');
+        mmm = scan_connect (temp, world->numpop, world->numpop2, 'M');
+        ms = scan_connect (temp, world->numpop, world->numpop2, 's')/2;
+        mss = scan_connect (temp, world->numpop, world->numpop2, 'S')/2;
+        total -= cc + (tm > 0 ? tm-1 : 0);
+        total -= (mm > 0 ? mm-1 : 0 );
+        total -= ms;
+        total -= mss;
+        free(temp);
+        free(temp1);
+        free(temp2);
+      }
+    return total;
+}
