@@ -1096,6 +1096,7 @@ do_profiles (world_fmt * world, nr_fmt * nr, double *likes,
         i++;
     }
     nr->profilenum = z;
+    world->locus = world->loci;
     trials = maximize (world->param0, world, nr, kind, repkind);
     return trials;
 }
@@ -1691,7 +1692,7 @@ fill_helper (helper_fmt * helper, double *param, double *lparam,
     double theta1 = param[0];
     double denom = 0;
     helper->boolgamma = world->locus < world->loci ?
-                        FALSE : world->options->gamma;
+        (helper->analystype==PROFILE ? world->options->gamma : FALSE) : world->options->gamma;
     if (helper->boolgamma)
     {
         alpha = param[nr->numpop2];
