@@ -10,7 +10,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
  
-$Id: heating.c,v 1.12 2002/08/12 21:13:52 beerli Exp $
+$Id: heating.c,v 1.13 2002/11/09 20:06:12 beerli Exp $
  
 */
 #include "migration.h"
@@ -291,7 +291,7 @@ void adjust_temperatures(world_fmt ** universe, long hchains, long step, long st
         {
             universe[i]->treeswapcount=0;
             if(steps < HEATCHECKINTERVAL)
-                universe[i]->averageheat  = 1./universe[i]->heat[0];
+                universe[i]->averageheat  = 1./universe[i]->heat;
             else
                 universe[i]->averageheat  = 0.0;
         }
@@ -302,12 +302,12 @@ void adjust_temperatures(world_fmt ** universe, long hchains, long step, long st
         {
             universe[0]->averageheat= 1.0;
             delta = calloc(hchains,sizeof(double));
-            // FPRINTF(stdout,"\n%f %li\n",1./universe[0]->heat[0],universe[0]->treeswapcount);
+            // FPRINTF(stdout,"\n%f %li\n",1./universe[0]->heat,universe[0]->treeswapcount);
             for(i=1; i< hchains; i++)
             {
-                universe[i]->averageheat += (1./(universe[i]->heat[0] * corrsum ));
-                //  FPRINTF(stdout,"%f %li\n",1./universe[i]->heat[0],universe[i]->treeswapcount);
-                delta[i-1] = 1./universe[i]->heat[0] - 1./universe[i-1]->heat[0];
+                universe[i]->averageheat += (1./(universe[i]->heat * corrsum ));
+                //  FPRINTF(stdout,"%f %li\n",1./universe[i]->heat,universe[i]->treeswapcount);
+                delta[i-1] = 1./universe[i]->heat - 1./universe[i-1]->heat;
             }
             for(i=1; i< hchains; i++)
             {
@@ -319,11 +319,11 @@ void adjust_temperatures(world_fmt ** universe, long hchains, long step, long st
                         delta[i-1] *= bigger;
                 }
             }
-            universe[0]->heat[0] = 1.;
+            universe[0]->heat = 1.;
             universe[0]->treeswapcount=0;
             for(i=1; i< hchains; i++)
             {
-                universe[i]->heat[0] = 1./(1./universe[i-1]->heat[0] + delta[i-1]);
+                universe[i]->heat = 1./(1./universe[i-1]->heat + delta[i-1]);
                 universe[i]->treeswapcount=0;
             }
             free(delta);
