@@ -200,6 +200,8 @@ print_heating_progress2(FILE * file, worldoption_fmt * options,
 void            get_treedata(world_fmt * world, option_fmt * options);
 void            get_mighistdata(world_fmt * world, option_fmt * options);
 
+void change_longsum_times(world_fmt *world);
+
 extern void unset_penalizer_function(boolean inprofiles);
 
 /* Functions ++++++++++++++++++++++++++++++++++++++++++++++++ */
@@ -226,7 +228,7 @@ main(int argc, char **argv)
     MPI_Init(&argc, &argv);
     comm_world = MPI_COMM_WORLD;
     MPI_Comm_size(comm_world, &numcpu);
-    fprintf(stdout,"==> %i <===\n",numcpu);
+    //debug fprintf(stdout,"==> %i <===\n",numcpu);
     MPI_Comm_rank(comm_world, &myID);
     MYMPIBARRIER(comm_world);
 #ifdef SLOWNET
@@ -238,7 +240,7 @@ main(int argc, char **argv)
     //scalar version of migrate
     myID = MASTER;
     numcpu = 1;
-fprintf(stdout,"==> SINGLE CPU VERSION <==\n");
+//debug fprintf(stdout,"==> SINGLE CPU VERSION <==\n");
 #endif
     //random number seed global inits
     seed = malloc(sizeof(long) * 3);
@@ -480,6 +482,10 @@ combine_loci(char type, option_fmt * options, world_fmt * world, long *Gmax)
 
             decide_plot(world->options, world->options->lchains,
                         world->options->lchains, 'l');
+#ifdef LONGSUM
+            change_longsum_times(world); //multilocus
+#endif /*LONGSUM*/
+            
             estimateParameter(options->replicatenum, *Gmax, world, options,
                               world->cov[world->loci], 0 /* chain */ ,
                               type, kind, world->repkind);
@@ -925,6 +931,9 @@ analyze_olddata(world_fmt * world,
             {
                 world->locus = locus;
                 world->repkind = MULTIPLERUN;
+#ifdef LONGSUM
+                change_longsum_times(world);//multi run replicates
+#endif /*LONGSUM*/                
                 estimateParameter(options->replicatenum, Gmax, world, options,
                                   world->cov[locus], 1, 'l',
                                   SINGLELOCUS, world->repkind);
@@ -1226,6 +1235,9 @@ run_locus(world_fmt ** universe, int usize, option_fmt * options,
         if (options->bayes_infer)
             return;
 #endif
+#ifdef LONGSUM
+        change_longsum_times(EARTH);
+#endif /*LONGSUM*/        
         // over multiple replicates if present or single locus
         estimateParameter(options->replicatenum, *Gmax, EARTH, options,
                           EARTH->cov[locus], options->lchains, /*type*/ 'l',
@@ -1403,6 +1415,9 @@ void run_chains(world_fmt **universe,
         EARTH->repkind = SINGLECHAIN;
         kind = SINGLELOCUS;
         *Gmax = (EARTH->G > *Gmax) ? EARTH->G + 1 : (*Gmax);
+#ifdef LONGSUM
+        change_longsum_times(EARTH);
+#endif /*LONGSUM*/
         estimateParameter(rep, *Gmax, EARTH, options,
                         EARTH->cov[locus], chain, type, kind,
                         EARTH->repkind);
@@ -1489,9 +1504,99 @@ void run_replicate(long locus,
             if (runs < 0 && options->replicate && options->replicatenum == 0)
               {
                 EARTH->repkind = MULTIPLECHAIN;
+#ifdef LONGSUM
+                change_longsum_times(EARTH);
+#endif /*LONGSUM*/
                 estimateParameter(replicate, *Gmax, EARTH, options,
                                   EARTH->cov[locus], chains, type,
                                   SINGLELOCUS, EARTH->repkind);
               }
           } //end runs
 }
+
+#ifdef LONGSUM
+long find_chaincutoffs(double * treetime, world_fmt *world, long locus, long r)
+{
+    
+    long j;
+    long T;
+    double totaltime=0.;
+    long copies=0;
+    tarchive_fmt *atl;
+    atl = world->atl[r][locus].tl;
+    for(j=0;j< world->atl[r][locus].T;j++)
+      {
+        T = atl[j].longsumlen-1;
+        copies += atl[j].copies;
+        totaltime = atl[j].longsum[T].eventtime / 3.;
+        treetime[0] += totaltime;
+        treetime[1] += totaltime + totaltime;
+        treetime[2] += totaltime + totaltime + totaltime;
+    }
+    return copies;
+}
+
+void find_loci_cutoffs(double * treetime, world_fmt *world)
+{
+    long r;
+    long locus;
+    long count=0;
+    long repstart=0;
+    long repstop = 1;
+    memset(treetime,0,sizeof(double)*3);
+    set_replicates (world, world->repkind, world->rep, &repstart, &repstop);
+
+    for(locus=0; locus< world->loci; locus++)
+      {
+        for(r = repstart; r < repstop; r++)
+        {
+            count += find_chaincutoffs(treetime, world, locus, r);
+        }
+      }
+    treetime[0] /= (double)count;
+    treetime[1] /= (double)count;
+    treetime[2] /= (double)count;
+}
+
+
+void find_replicate_cutoffs(double * treetime, world_fmt *world)
+{
+    long r;
+    long count=0;
+    long repstart=0;
+    long repstop = 1;
+    memset(treetime,0,sizeof(double)*3);
+    set_replicates (world, world->repkind, world->rep, &repstart, &repstop);
+
+    for(r = repstart; r < repstop; r++)
+        {
+        count += find_chaincutoffs(treetime, world, world->locus, r);
+        }
+    treetime[0] /= (double)count;
+    treetime[1] /= (double)count;
+    treetime[2] /= (double)count;
+}
+
+
+
+void change_longsum_times(world_fmt *world)
+{
+    long i;
+    long numpop3 = 3 * world->numpop;
+    long numpop6 = 2 * numpop3;
+    double *treetime;
+    treetime = (double *) calloc(3, sizeof(double));// we have 3 classes
+    if(world->locus < world->loci)        
+        find_replicate_cutoffs(treetime,world);
+    else
+        find_loci_cutoffs(treetime,world);
+    for(i=numpop3; i < numpop6; i += 3)
+      {
+        world->flucrates[i] = treetime[0];
+        world->flucrates[i+1] = treetime[1];
+        world->flucrates[i+2] = treetime[2];
+      }
+    free(treetime);
+}
+
+#endif /*LONGSUM*/
