@@ -17,7 +17,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c,v 1.62 2002/08/12 21:13:54 beerli Exp $
+$Id: mcmc1.c,v 1.63 2002/11/09 20:06:12 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "random.h"
@@ -1111,11 +1111,11 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
 
     boolean report = TRUE;
     long oldg = -1;
-    double *zz;
+    //double zz;
     double rr, expo;
     long rm;
     long rmc = rmigrcount (proposal);
-    zz = world->heat;
+    //zz = world->heat;
     if ((rm =
                 proposal->migr_table_counter + proposal->migr_table_counter2 +
                 world->migration_counts - rmc) > MIGRATION_LIMIT * world->numpop)
@@ -1167,7 +1167,7 @@ acceptlike (world_fmt * world, proposal_fmt * proposal, long g,
     }
     else
     {
-        expo = (proposal->likelihood - world->likelihood[g]) * world->heat[0];
+        expo = (proposal->likelihood - world->likelihood[g]) * world->heat;
         rr = LOG (RANDUM ());
         if (rr < expo)
             return TRUE;
