@@ -15,7 +15,7 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: menu.c,v 1.58 2002/08/12 21:13:54 beerli Exp $
+$Id: menu.c,v 1.60 2002/11/27 16:17:14 beerli Exp $
  
 -------------------------------------------------------*/
 #include "migration.h"
@@ -127,7 +127,7 @@ print_menu_accratio (long a, long b, world_fmt *world)
 #ifdef MPI
 		filehandle1 = get_filehandle2(stdout, world);
 		bufsize = sprintf(finalbuffer,"%c%li:%s",'M',filehandle1,buffer);
-		MPI_Send (finalbuffer, bufsize, MPI_CHAR, MASTER, myID, comm_world);
+		MYMPISEND (finalbuffer, bufsize, MPI_CHAR, MASTER, myID, comm_world);
 #else
 		FPRINTF(stdout,"%s",buffer);
 #endif
@@ -137,7 +137,7 @@ print_menu_accratio (long a, long b, world_fmt *world)
 #ifdef MPI
 		filehandle2 = get_filehandle2(world->options->logfile, world);
 		bufsize = sprintf(finalbuffer,"%c%li:%s",'M',filehandle2,buffer);
-		MPI_Send (finalbuffer, bufsize, MPI_CHAR, MASTER, myID, comm_world);
+		MYMPISEND (finalbuffer, bufsize, MPI_CHAR, MASTER, myID, comm_world);
 #else
 		FPRINTF(world->options->logfile,"%s",buffer);
 #endif
@@ -379,12 +379,17 @@ menuData (option_fmt * options, char datatype[])
         case 'a':
             printf
             ("          (using a k-allele model which simulates an infinite allele model)\n");
-
+            printf ("  2       Discard missing data:      %3s\n", options->include_unknown ? "YES" : " NO");
+            break;
+        case 'b':
+            printf
+            ("          (using a Brownian motion model which simulates a stepwise mutation model)\n");
+            printf ("  2       Discard missing data:      %3s\n", options->include_unknown ? "YES" : " NO");
             break;
         case 'm':
             printf ("          (using a stepwise mutation model)\n");
-            //      printf ("  2       Size of the step matrix:      %li\n", options->micro_stepnum);
-            printf ("  2       Threshold value:              %li\n\n\n\n",
+            printf ("  2       Discard missing data:      %3s\n", options->include_unknown ? "YES" : " NO");
+            printf ("  3       Threshold value:              %li\n\n\n\n",
                     options->micro_threshold);
             break;
         case 'u':
@@ -453,16 +458,41 @@ menuData (option_fmt * options, char datatype[])
         default:
             break;
         }
+        if (strchr("ab",options->datatype))
+          {
+            switch (atol (input))
+              {
+                case 2:         /*discard unkowns */
+                    printf ("  Include missing Alleles (YES|NO)?\n");
+                    printf ("  [Default is NO, this is the best choice for most situations]\n");
+                    FGETS (input, LINESIZE, stdin);
+                    if(strchr("Nn",input[0]))
+                        options->include_unknown = FALSE;
+                    else
+                       options->include_unknown = TRUE;
+                    input[0]='\0';    
+
+                       break;
+                default:
+                       break;
+                }
+            
+            }
         if (options->datatype == 'm')
         {
             switch (atol (input))
             {
-                //case 2:         /*micro-stepmax */
-                //printf ("  What is the maximal size of the stepmatrix?\n");
-                //printf ("  [the bigger the longer the run and the more accurate the estimate]\n");
-                //fscanf (stdin, "%ld%*[^\n]", &options->micro_stepnum);
-                //break;
-            case 2:  /*micro-threshold */
+            case 2:         /*discard unkowns */
+                printf ("  Discard missing Alleles?\n");
+                printf ("  [Default is YES, this is the best choice for most situations]\n");
+                FGETS (input, LINESIZE, stdin);
+                if(strchr("Yy",input[0]))
+                   options->include_unknown = TRUE;
+                else
+                   options->include_unknown = FALSE;
+
+                   break;
+            case 3:  /*micro-threshold */
                 printf ("  What is the threshold value?\n");
                 printf
                 ("  E.g. if your allele is 24 and the threshold is 10\n");
@@ -1070,9 +1100,16 @@ menuInput (option_fmt * options)
             set_profile_options (options);
             break;
         case MI_LRT:
-            FPRINTF (stdout, "  Likelihood-Ratio tests:\n");
-            FPRINTF (stdout, "  -----------------------\n");
-            read_custom_menu_lratio (options);
+            if(options->lratio->counter>0)
+              {
+                options->lratio->counter=0;
+              }
+            else
+              {
+                FPRINTF (stdout, "  Likelihood-Ratio tests:\n");
+                FPRINTF (stdout, "  -----------------------\n");
+                read_custom_menu_lratio (options);
+              }
             break;
         case MI_AIC:
             printf
@@ -1905,10 +1942,10 @@ display_lratio_menutext (void)
     printf ("  H0: the ML-estimates and your values are the same\n");
     printf ("  H1: the ML-estimates and your values are different\n");
     printf ("  You need to specify values for ALL parameters\n");
-    printf ("  Beware! If you restrict the migration model some test\n");
-    printf (" will not work. This test assumes that your hypothesis\n");
-    printf ("  is nested in in the hypothesis you test against.\n");
-    printf ("  Currently you cannot specify < or > comparisons AND\n");
+    printf ("  Beware! If you restrict the migration model then some test\n");
+    printf ("  will not work. This test assumes that your hypothesis\n");
+    printf ("  is nested in the hypothesis you test against.\n");
+    printf ("  Currently you cannot specify \"<\" or \">\" comparisons AND\n");
     printf ("  averages of migration rates are calculated and not\n");
     printf ("  averages  for number of migrants\n\n");
 }
@@ -2029,6 +2066,9 @@ check_lrt_allocation (lratio_fmt * lratio)
                 (char *) calloc (1, sizeof (char) * LINESIZE);
             lratio->data[i].value2 =
                 (char *) calloc (1, sizeof (char) * LINESIZE);
+            lratio->data[i].connect =
+                (char *) calloc (1, sizeof (char) * LINESIZE);
+
         }
     }
 }
