@@ -43,8 +43,9 @@ typedef struct lr_data_fmt
 {
     short type;
     long elem;
-    char *value1;
-    char *value2;
+    char *value1; // values to test using a mix of numbers and m,c, etc
+    char *value2; // not used, reserved fo pairwise tests 
+    char *connect;// custom migration matrix for value1 [no user interaction]
 }
 lr_data_fmt;
 
@@ -171,22 +172,27 @@ typedef struct _option
     FILE *seedfile;
     FILE *logfile;
     /*general options */
+    //
+    // name length
     long nmlength;  /* length of individual names */
     long popnmlength;  /* length of population names */
     long allelenmlength;  /* length of allele names */
+    //
+    // custom migration matrix setup
     char *custm;   /* custom migration matrix: theta are first */
     char *custm2;   /*custom migration matrix: theta on diagonal */
-    long zeron;
-    long *zeroparam;
-    long constn;
-    long *constparam;
-    long symn;
-    long sym2n;
-
-    twin_fmt *symparam;
-    quad_fmt *sym2param;
-    long mmn;
-    long *mmparam;
+    //long symn;
+    //long sym2n;
+    //long zeron;
+    //long constn;
+    //long tmn;
+    //long mmn;
+   // long *zeroparam;
+   // long *constparam;
+   // twin_fmt *symparam;
+   // quad_fmt *sym2param;
+   // long *mmparam;
+    
     /*input/output options */
     int menu;
     boolean progress;
@@ -263,6 +269,7 @@ typedef struct _option
 
     /* data options */
     char datatype;
+  boolean include_unknown;
     short migration_model;
     char dlm;
     long micro_stepnum;
@@ -331,7 +338,7 @@ typedef struct _option
     long replicatenum;
     long gridpoints;
     long numpop;
-    double heat[20];
+    double heat[50];
     boolean adaptiveheat;
     long heating_interval;
     long heated_chains;
@@ -340,6 +347,9 @@ typedef struct _option
     boolean writesum;
     /* threading over loci */
     int cpu;
+    //
+    // fatal attraction of zero resistance
+    double minmigsumstat;
 }
 option_fmt;
 
@@ -545,6 +555,7 @@ typedef struct _worldoption
     long sym2n;
     twin_fmt *symparam;
     quad_fmt *sym2param;
+    long tmn;
     long mmn;
     long *mmparam;
     boolean mixplot;
@@ -615,7 +626,7 @@ typedef struct _worldoption
     boolean fastlike;
     boolean bayes_infer;
 	double updateratio;
-
+    double minmigsumstat;
 }
 worldoption_fmt;
 
@@ -714,7 +725,7 @@ typedef struct _world
     long actualinc;
     long increment;
     //  double heatratio;
-    double *heat;
+    double heat;
     double averageheat;
     long treeswapcount;
     /* reporting time */
@@ -758,8 +769,9 @@ typedef struct _world
     long *oldrootuep;
     long **uepanc;
 #endif
-
     long accept;
+    double accept_freq;
+    long swapped;
     long G;
 #ifdef BAYESUPDATE
 	long bayesaccept;
