@@ -1331,8 +1331,6 @@ find_profilelike (double testlike, double prob, long whichprob, double minparam,
     double x, mid = -DBL_MAX;
     double xhigh, high;
     long panic = 0;
-//    long rep =     world->options->replicate ? (world->loci > 1 ? 0 : world->repstop) : 0;
-//    long loc = world->loci > 1 ? world->loci : 0;
     helper_fmt helper;
     double *ltestparam;
     long len = world->numpop2 +  (long) world->options->gamma;
@@ -1340,7 +1338,10 @@ find_profilelike (double testlike, double prob, long whichprob, double minparam,
 
     len += world->numpop * 3;
 #endif /*LONGSUM*/
-
+    world->locus = world->loci; // in case we have used gamma
+    // used to set gamma option correctly, overly complicated, need
+    // revamping, because the gamma test is all over the place PB022403
+    
     ltestparam = (double *) calloc (len, sizeof (double));
     *normd = -1;
     prepare_broyden (PROFILE, world, &helper.multilocus);
