@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c,v 1.43 2002/08/12 22:09:49 beerli Exp $
+ $Id: sequence.c,v 1.44 2002/08/27 01:27:49 beerli Exp $
  
 -------------------------------------------------------*/
 
@@ -1126,11 +1126,12 @@ inputweights (world_fmt * world, data_fmt * data, long chars)
     /* input the character weights, 0-9 and A-Z for weights 0 - 35 */
     char ch;
     long i;
+	char input[1024];
+
     ch = getc (data->weightfile);
     while (ch == '#')
     {
-        while (ch != '\n')
-            ch = getc (data->weightfile);
+        FGETS(input, LINESIZE,data->weightfile);
         ch = getc (data->weightfile);
     }
     ungetc (ch, data->weightfile);
@@ -1170,11 +1171,11 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options,
     /* input the categories, 1-9 */
     char ch;
     long i;
+	char input[LINESIZE];
     ch = getc (data->catfile);
     while (ch == '#')
     {
-        while (ch != '\n')
-            ch = getc (data->catfile);
+        FGETS(input, LINESIZE,data->catfile);
         ch = getc (data->catfile);
     }
     ungetc (ch, data->catfile);
@@ -1188,21 +1189,22 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options,
 
     for (i = a; i < b; i++)
     {
-        do
-        {
-            ch = getc (data->catfile);
-            if (ch == '\n')
-                ch = ' ';
-        }
-        while (ch == ' ');
         if ((ch >= '1') && (ch <= ('0' + world->options->categs)))
             world->data->seq->category[i] = ch - '0';
         else
         {
-            printf
+			if(isspace((int) ch))
+			  {
+				i--;
+				continue;
+			  }
+			else
+			  {
+				printf
             ("BAD CATEGORY CHARACTER: %c -- CATEGORIES ARE CURRENTLY 1-%ld\n",
              ch, world->options->categs);
             exit (EXIT_FAILURE);
+			  }
         }
     }
 }    /* inputcategs */
