@@ -19,9 +19,10 @@ Copyright 2001 Peter Beerli and Joseph Felsenstein
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c,v 1.56 2002/08/12 21:13:57 beerli Exp $
+$Id: tools.c,v 1.60 2002/12/22 04:50:46 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
+#include "sighandler.h"
 #include "data.h"
 #include "world.h"
 #include "random.h"
@@ -171,29 +172,65 @@ logfac (long n)
     case 0:
         return 0.;
     case 1:
-        return 0.;
+      return 0.;
     case 2:
-        return 0.693147180559945309417232121458;
+      return 0.693147180559945309417232121458;
     case 3:
-        return 1.791759469228055000812477358381;
+      return 1.791759469228055000812477358381;
     case 4:
-        return 3.1780538303479456196469416013;
+      return 3.1780538303479456196469416013;
     case 5:
-        return 4.78749174278204599424770093452;
+      return 4.78749174278204599424770093452;
     case 6:
-        return 6.5792512120101009950601782929;
+      return 6.5792512120101009950601782929;
     case 7:
-        return 8.52516136106541430016553103635;
+      return 8.52516136106541430016553103635;
     case 8:
-        return 10.60460290274525022841722740072;
+      return 10.60460290274525022841722740072;
     case 9:
         return 12.80182748008146961120771787457;
     case 10:
-        return 15.10441257307551529522570932925;
+      return 15.10441257307551529522570932925;
     case 11:
-        return 17.50230784587388583928765290722;
+      return 17.50230784587388583928765290722;
     case 12:
-        return 19.98721449566188614951736238706;
+      return 19.98721449566188614951736238706;
+    case 13:
+      return 22.5521638531234228855708498286;
+    case 14:
+      return 25.1912211827386815000934346935;
+    case 15:
+      return 27.8992713838408915660894392637;
+    case 16:
+      return 30.6718601060806728037583677495;
+    case 17:
+      return 33.5050734501368888840079023674;
+    case 18:
+      return 36.3954452080330535762156249627;
+    case 19:
+      return 39.3398841871994940362246523946;
+    case 20:
+      return 42.3356164607534850296598759707;
+    case 21:
+      return 45.3801388984769080261604739511;
+    case 22:
+      return 48.4711813518352238796396496505;
+    case 23:
+      return 51.6066755677643735704464024823;
+    case 24:
+      return 54.7847293981123191900933440836;
+    case 25:
+      return 58.0036052229805199392948627501;
+    case 26:
+      return 61.2617017610020019847655823131;
+    case 27:
+      return 64.5575386270063310589513180238;
+    case 28:
+      return 67.8897431371815349828911350102;
+    case 29:
+      return 71.2570389671680090100744070426;
+    case 30:
+      return 74.6582363488301643854876437342;
     default:
         return LGAMMA (n + 1.);
     }
@@ -206,13 +243,16 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 {
 	long *tempdb;
 #ifdef MPI
-	char tempfilenum=0;
 	long i,j;
 #endif
-	tempdb = calloc(20*2+1,sizeof(long));
+    long maxfilenum = 41; //20*2+1;
+	tempdb = calloc(maxfilenum,sizeof(long));
 	
     if (myID == MASTER)
     {
+#ifdef MPI
+        setup_filehandle_db((void *) stdout, world, options,data);
+#endif
 		if (!options->readsum)
 		{
 			openfile (&data->infile, options->infilename, "r+", appl, NULL);
@@ -297,23 +337,22 @@ init_files (world_fmt * world, data_fmt * data, option_fmt * options)
 			tempdb[j++] = (long) filedb[i].file;
 			tempdb[j++] = (long) filedb[i].handle;
 		}
-		tempfilenum = filenum * 2 + 1;
-		MPI_Bcast (tempdb, tempfilenum, MPI_LONG, MASTER, comm_world);
+		MYMPIBCAST (tempdb, maxfilenum, MPI_LONG, MASTER, comm_world);
 #endif
     }
 	else
 	  {
 		// all non myID==MASTER
 #ifdef MPI
-		MPI_Bcast (tempdb, 20*2+1, MPI_LONG, MASTER, comm_world);
+		MYMPIBCAST (tempdb, maxfilenum, MPI_LONG, MASTER, comm_world);
 		filenum = tempdb[0]; 
 		for(i=0, j=1;i<filenum;i++)
 		  {
 			filedb[i].file = (FILE *) tempdb[j++];
-			filedb[i].file = (FILE *) tempdb[j++];
+			filedb[i].handle =  tempdb[j++];
 		  }
 		//assumess same order as in the master
-		j=0;
+		j=1; //zero is stdout
 		world->outfile = filedb[j++].file;
 		if (options->mighist)
 			world->mighistfile = filedb[j++].file;
@@ -477,6 +516,16 @@ print_llike (double llike, char *strllike)
         sprintf (strllike, "%-10.5f", llike);
 }
 
+
+void remove_trailing_blanks(char **filename)
+{
+  int pos;;
+  pos = strlen(*filename);
+  while (isspace( (*filename)[pos]) && pos>0)
+    pos--;
+  (*filename)[pos] = '\0';   
+}
+
 void
 openfile (FILE ** fp, char *filename, char *mode, const char *application,
           char *perm)
@@ -487,6 +536,7 @@ openfile (FILE ** fp, char *filename, char *mode, const char *application,
     char *p;
     if ((p = strpbrk (filename, CRLF)) != NULL)
         *p = '\0';
+    remove_trailing_blanks(&filename);
     strncpy (file, filename, LINESIZE - 1);
     // not needed anymore?
     //file[strlen (file) - 1] = '\0';
@@ -581,6 +631,15 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
         {
             newstyle = TRUE;
             FGETS (input, 1024, sumfile);
+            if(input[0]=='M') // added custom migration model 11-25-02
+              {
+                options->custm = realloc(options->custm, sizeof(char) * (strlen(input)+1));
+                strcpy(options->custm,input+6);
+                FGETS (input, 1024, sumfile);
+                options->custm2 = realloc(options->custm2, sizeof(char) * (strlen(input)+1));
+                strcpy(options->custm2,input+6);
+                FGETS (input, 1024, sumfile);
+              }
         }
         else
             newstyle = FALSE;
@@ -686,7 +745,7 @@ read_savesum (world_fmt * world, option_fmt * options, data_fmt * data)
     listofthings[5] = Gmax;
     //printf("listofthings sent");
     fflush(stdout);
-    MPI_Bcast (listofthings,5, MPI_LONG, MASTER, comm_world);
+    MYMPIBCAST (listofthings,5, MPI_LONG, MASTER, comm_world);
 #endif
 
     return Gmax;
@@ -712,6 +771,8 @@ write_savesum (world_fmt * world)
     fprintf (sumfile,
              "# begin genealogy-summary file of migrate %s ------\n#\n",
              MIGRATEVERSION);
+    fprintf (sumfile,"Model=%s\n",world->options->custm);
+    fprintf (sumfile,"Mode2=%s\n",world->options->custm2);
     fprintf (sumfile, "%li %li %li %li %li\n", world->loci, world->numpop,
              world->numpop2, (long) world->options->replicate, repmax);
     for (l = 0; l < world->loci; l++)
@@ -2092,6 +2153,7 @@ probchi (long df, double chi)
 {
     double prob;
     double v = ((double) df) / 2.;
+    
     if (chi > DBL_EPSILON && v > DBL_EPSILON)
     {
         //lg = EXP (LGAMMA (v));
@@ -2113,6 +2175,8 @@ probchiboundary (double chi, long zeros, long all)
     double xa = 0.0;  //EPSILON/1000.;
     double xm = 0.51;
     double nonzeros = all - zeros;
+    if(all==0)
+        return 1.;
     if (zeros == 0)
     {
         return probchi (all, chi);
